% example Quokka3 settingsfile to fit a lifetime curve using a full drift-diffusion 1D simulation
% thereby one can fit detailed physical properties of the surfaces instead of effective recombination parameters J0 or Seff

% data from Fig. 5 in: B. Hammann et al., in IEEE Journal of Photovoltaics, vol. 13, no. 4, pp. 535-546, July 2023, doi: 10.1109/JPHOTOV.2023.3265859

% (c) 2023 AF Simulations GmbH

Syntax = 'generic';

Optim.Enable = 1;
Optim.Variable(1).Parameter = 'SkinFeature(1).Layer(1).SurfaceRecombination.Sn'; % fit fundamental electron SRV of the Al2O3 passivation
Optim.Variable(1).Guess = 3e3 ;
Optim.Variable(1).UpperBound = 1e4;
Optim.Variable(1).LowerBound = 1e2;
Optim.Variable(2).Parameter = 'Bulk.Electrical.Recombination.SRH(1).Nt'; % fit Fei defect density
Optim.Variable(2).Guess = 2e9;
Optim.Variable(2).UpperBound = 1e11;
Optim.Variable(2).LowerBound = 1e8;

Optim.Goal(1).Type = 'curve';
Optim.Goal(1).XResultName = '/Curves/deltanAvg';
Optim.Goal(1).YResultName = '/Curves/taueff';
Optim.Goal(1).Curve.Type = 'file';
Optim.Goal(1).Curve.File = 'tau_dn.csv'; % the measured lifetime curve
Optim.Goal(1).CurveWeightsType = 'equal'; % equal means the relative deviation to each datapoint matters, should be used for curves with large differences in absolute values
Optim.Goal(1).CurveRange.Enable = 1;
Optim.Goal(1).CurveRange.Xmin = 5e13; % exclude low injection points with too much noise and errors
Optim.Goal(1).CurveRange.Xmax = 1.5e16; % exclude high injection points outside valid transient regime


Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 126 um; % half of actual 252um due to symmetry

Solver.SolutionType = 'sunsVoc-curve'; % sunsVoc-curve varies illumination intensity and simulates OC conditions, resulting in tauff(dn) datapoints - the lifetime curve
Solver.Electrical.BulkModelType = 'full'; % uses full (not quasi-neutral) drift-diffusion current transport model, only possible in 1D
Solver.Electrical.MetalModelType = 'constant-potential';

Optical.GenerationModelType = 'defined-generation';
Optical.DefinedGeneration.Type = 'uniform-Jgen'; % assumes that depth-wise carrier profile (and generation profile) doesn't matter, which is true for moderate to high lifetime samples
Optical.DefinedGeneration.UniformJgen = 40; % value doesn't matter, it is varied anyway in the suns-Voc simulation

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.09;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'sigma-Et-Nt'; % Fei defect properties from Istratov et al. Appl. Phys. A: Mater. Sci.
Bulk.Electrical.Recombination.SRH(1).sigman = 4e-14;
Bulk.Electrical.Recombination.SRH(1).sigmap = 6.8e-17;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = -0.16;
Bulk.Electrical.Recombination.SRH(1).Nt = 2e9;
Bulk.Electrical.Recombination.SRH(1).vth = 1.1e7;


SkinFeature(1).Name = 'front skin';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).ElectricalModelType = 'detailed';
SkinFeature(1).Layer(1).Type = 'near-surface';
SkinFeature(1).Layer(1).Name = 'Al2O3 passivation';
SkinFeature(1).Layer(1).DopingProfile.Type = 'off';
SkinFeature(1).Layer(1).SurfaceRecombination.Type = 'S';
SkinFeature(1).Layer(1).SurfaceRecombination.Et_Ei = 0;
SkinFeature(1).Layer(1).SurfaceRecombination.Sn = 1e3;
SkinFeature(1).Layer(1).SurfaceRecombination.Sp = 1e7;
SkinFeature(1).Layer(1).SurfaceRecombination.FixedCharge = -5e12; % guess only

SkinFeature(2).Name = 'rear skin'; % perfect rear side equivalent to symmetry plane for OC conditions
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).ElectricalModelType = 'detailed';
SkinFeature(2).Layer(1).Type = 'near-surface';
SkinFeature(2).Layer(1).Name = 'ideal rear side'; % equivalent to symmetry plane for OC conditions
SkinFeature(2).Layer(1).DopingProfile.Type = 'off';
SkinFeature(2).Layer(1).SurfaceRecombination.Type = 'off';


% the 1D full drift-diffusion solver does not converge well for a non-contacted device
% therefore "virtual contacts" are added; for OC conditions they have no influence besides improved convergence
% in this case we have to employ symmetry in order to place an ideal n-type virtual contact at the rear

ContactFeature(1).Name = 'front contact';
ContactFeature(1).Geometry.Plane = 'front';
ContactFeature(2).Name = 'rear contact';
ContactFeature(2).Geometry.Plane = 'rear';

MetalFeature(1).Name = 'front metal';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Electrical.Polarity = 'p-type';
MetalFeature(2).Name = 'rear metal';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Electrical.Polarity = 'n-type';

